@@ -3,19 +3,12 @@ use std::fs::File;
 use super::{Render, RenderContext};
 use crate::error::*;
 use crate::project::{Output, Project};
-use crate::PROGRAM_META;
 
 pub struct RJson;
 
 impl Render for RJson {
     fn render<'a>(project: &'a Project, output: &'a Output) -> Result<&'a Output> {
-        let context = RenderContext {
-            book: project.metadata(),
-            songs: project.songs(),
-            output: &output.metadata,
-            program: PROGRAM_META,
-        };
-
+        let context = RenderContext::new(project, output);
         let path = &output.file;
 
         File::create(&path)
