@@ -1,10 +1,12 @@
-use std::env;
+use std::fs;
 use std::path::{self, Path, PathBuf};
 use std::process::ExitStatus;
 
 #[cfg(unix)]
 use std::os::unix::process::ExitStatusExt as _;
 
+use lexical_sort::{lexical_cmp, PathSort};
+
 use crate::error::*;
 
 pub type BStr = Box<str>;
@@ -77,32 +79,49 @@ impl ExitStatusExt for ExitStatus {
     }
 }
 
-// CwdGuard
+// Lexical sorting
+// Basically forwards to the lexical-sort crate
 
-/// Used for globbing, which doesn't support setting base for relative globs
-pub struct CwdGuard {
-    orig_path: PathBuf,
+pub fn sort_lexical<S>(slice: &mut [S])
+where
+    S: AsRef<str>,
+{
+    sort_lexical_by(slice, AsRef::as_ref)
 }
 
-impl CwdGuard {
-    pub fn new<P>(new_path: P) -> Result<Self>
-    where
-        P: AsRef<Path>,
-    {
-        let mut orig_path = env::current_dir().context("Could not read current directory")?;
+pub fn sort_lexical_by<T, F>(slice: &mut [T], mut key_fn: F)
+where
+    F: FnMut(&T) -> &str,
+{
+    slice.sort_by(|lhs, rhs| lexical_cmp(key_fn(lhs), key_fn(rhs)));
+}
 
-        let new_path = new_path.as_ref();
-        env::set_current_dir(new_path).with_context(|| {
-            orig_path.push(new_path);
-            format!("Could not enter directory: `{}`", orig_path.display())
-        })?;
+pub fn sort_paths_lexical<S>(slice: &mut [S])
+where
+    S: AsRef<Path>,
+{
+    slice.path_sort(lexical_cmp);
+}
 
-        Ok(Self { orig_path })
+// fs utils
+
+fn read_dir_all_inner(res: &mut Vec<PathBuf>, path: &Path) -> Result<()> {
+    for entry in fs::read_dir(path)? {
+        let entry = entry?;
+        let path = entry.path();
+        if entry.file_type()?.is_dir() {
+            // Recurse
+            read_dir_all_inner(res, &path)?;
+        } else {
+            res.push(path);
+        }
     }
+
+    Ok(())
 }
 
-impl Drop for CwdGuard {
-    fn drop(&mut self) {
-        let _ = env::set_current_dir(&self.orig_path);
-    }
+pub fn read_dir_all<P: AsRef<Path>>(path: P) -> Result<Vec<PathBuf>> {
+    let mut res = vec![];
+    read_dir_all_inner(&mut res, path.as_ref())?;
+    Ok(res)
 }
